<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="am">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="128"/>
        <source>MX Package Installer</source>
        <translation>MX ጥቅል መግጠሚያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="57"/>
        <source>Popular Applications</source>
        <translation>የ ተመረጠው መተግበሪያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <source>Package</source>
        <translation>ጥቅል </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <source>Info</source>
        <translation>መረጃ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <location filename="../mainwindow.ui" line="420"/>
        <location filename="../mainwindow.ui" line="817"/>
        <location filename="../mainwindow.ui" line="1074"/>
        <source>Description</source>
        <translation>መግለጫ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Manage popular packages&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <location filename="../mainwindow.ui" line="190"/>
        <location filename="../mainwindow.ui" line="686"/>
        <location filename="../mainwindow.ui" line="1099"/>
        <location filename="../mainwindow.ui" line="1321"/>
        <source>search</source>
        <translation>መፈለጊያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="149"/>
        <location filename="../mainwindow.ui" line="203"/>
        <location filename="../mainwindow.ui" line="699"/>
        <location filename="../mainwindow.ui" line="1167"/>
        <location filename="../mainwindow.ui" line="1293"/>
        <source>= Installed packages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="172"/>
        <source>Enabled Repos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Remove all the packages that are marked as &amp;quot;autoremovable&amp;quot;. If you want to manage them, select Autoremovable from drop-down selection box.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="233"/>
        <source>Autoremove packages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <location filename="../mainwindow.ui" line="1384"/>
        <source>Upgrade All</source>
        <translation>ሁሉንም ማሻሻያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="284"/>
        <location filename="../mainwindow.ui" line="547"/>
        <location filename="../mainwindow.ui" line="926"/>
        <source>Installed:</source>
        <translation>ተገጥሟል:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="368"/>
        <location filename="../mainwindow.ui" line="540"/>
        <location filename="../mainwindow.ui" line="947"/>
        <source>Total packages:</source>
        <translation>ጠቅላላ ጥቅሎች</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="354"/>
        <location filename="../mainwindow.ui" line="662"/>
        <location filename="../mainwindow.ui" line="987"/>
        <source>Also Install &quot;Recommended&quot; Packages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="314"/>
        <location filename="../mainwindow.ui" line="577"/>
        <location filename="../mainwindow.ui" line="919"/>
        <source>Upgradable:</source>
        <translation>ሊሻሻል የሚችል</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="243"/>
        <location filename="../mainwindow.ui" line="584"/>
        <location filename="../mainwindow.ui" line="954"/>
        <source>Hide library and developer packages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="265"/>
        <location filename="../mainwindow.ui" line="633"/>
        <location filename="../mainwindow.ui" line="1006"/>
        <source>Refresh list</source>
        <translation>ዝርዝር ማነቃቂያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="481"/>
        <location filename="../mainwindow.ui" line="758"/>
        <location filename="../mainwindow.ui" line="1129"/>
        <location filename="../mainwindow.ui" line="1245"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filter packages according to their status.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="484"/>
        <location filename="../mainwindow.ui" line="488"/>
        <location filename="../mainwindow.ui" line="761"/>
        <location filename="../mainwindow.ui" line="765"/>
        <location filename="../mainwindow.ui" line="1132"/>
        <location filename="../mainwindow.ui" line="1136"/>
        <location filename="../mainwindow.cpp" line="2827"/>
        <source>All packages</source>
        <translation>ሁሉም ጥቅሎች </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="493"/>
        <location filename="../mainwindow.ui" line="770"/>
        <location filename="../mainwindow.ui" line="1141"/>
        <location filename="../mainwindow.cpp" line="2847"/>
        <source>Installed</source>
        <translation>የ ተገጠመው</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <location filename="../mainwindow.ui" line="775"/>
        <location filename="../mainwindow.ui" line="1146"/>
        <location filename="../mainwindow.cpp" line="2848"/>
        <source>Upgradable</source>
        <translation>ሊሻሻል የሚችል</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="503"/>
        <location filename="../mainwindow.ui" line="780"/>
        <location filename="../mainwindow.ui" line="1151"/>
        <location filename="../mainwindow.ui" line="1282"/>
        <location filename="../mainwindow.cpp" line="2813"/>
        <location filename="../mainwindow.cpp" line="2849"/>
        <location filename="../mainwindow.cpp" line="2951"/>
        <location filename="../mainwindow.cpp" line="2952"/>
        <source>Not installed</source>
        <translation>አልተገጠመም</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <location filename="../mainwindow.ui" line="785"/>
        <location filename="../mainwindow.ui" line="1156"/>
        <location filename="../mainwindow.cpp" line="2363"/>
        <location filename="../mainwindow.cpp" line="2786"/>
        <location filename="../mainwindow.cpp" line="2850"/>
        <location filename="../mainwindow.cpp" line="2936"/>
        <source>Autoremovable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="450"/>
        <location filename="../mainwindow.ui" line="727"/>
        <location filename="../mainwindow.ui" line="855"/>
        <source>= Upgradable package. Newer version available in selected repository.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="405"/>
        <location filename="../mainwindow.ui" line="802"/>
        <location filename="../mainwindow.ui" line="1059"/>
        <source>Package Name</source>
        <translation>የ ጥቅል ስም</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1513"/>
        <source>Version</source>
        <translation>እትም</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>MX Test Repo</source>
        <translation>MX መሞከሪያ ማጠራቀሚያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="410"/>
        <location filename="../mainwindow.ui" line="807"/>
        <location filename="../mainwindow.ui" line="1064"/>
        <source>Repo Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="415"/>
        <location filename="../mainwindow.ui" line="812"/>
        <location filename="../mainwindow.ui" line="1069"/>
        <source>Installed Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="837"/>
        <source>Debian Backports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1190"/>
        <source>Flatpaks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1196"/>
        <location filename="../mainwindow.ui" line="1200"/>
        <location filename="../mainwindow.cpp" line="113"/>
        <location filename="../mainwindow.cpp" line="114"/>
        <source>For all users</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1205"/>
        <source>For current user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1213"/>
        <source>Remote (repo):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1248"/>
        <location filename="../mainwindow.ui" line="1252"/>
        <location filename="../mainwindow.cpp" line="2795"/>
        <source>All apps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1257"/>
        <location filename="../mainwindow.cpp" line="2801"/>
        <source>All runtimes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1262"/>
        <location filename="../mainwindow.cpp" line="2807"/>
        <source>All available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1267"/>
        <location filename="../mainwindow.cpp" line="2792"/>
        <source>Installed apps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1272"/>
        <location filename="../mainwindow.cpp" line="2789"/>
        <source>Installed runtimes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1277"/>
        <location filename="../mainwindow.cpp" line="2811"/>
        <location filename="../mainwindow.cpp" line="2944"/>
        <location filename="../mainwindow.cpp" line="2945"/>
        <source>All installed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1363"/>
        <source>Total items </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1377"/>
        <source>Installed apps:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1429"/>
        <source>Advanced</source>
        <translation>የረቀቀ </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1458"/>
        <source>Total installed size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1472"/>
        <source>Remove unused runtimes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1503"/>
        <source>Short Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1508"/>
        <source>Full Package Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1518"/>
        <source>Size</source>
        <translation>መጠን</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1548"/>
        <location filename="../mainwindow.cpp" line="2505"/>
        <location filename="../mainwindow.cpp" line="2721"/>
        <source>Console Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1554"/>
        <source>Enter</source>
        <translation>ማስገቢያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1564"/>
        <source>Respond here, or just press Enter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1623"/>
        <location filename="../mainwindow.cpp" line="1178"/>
        <location filename="../mainwindow.cpp" line="2837"/>
        <location filename="../mainwindow.cpp" line="2845"/>
        <location filename="../mainwindow.cpp" line="2935"/>
        <location filename="../mainwindow.cpp" line="2941"/>
        <location filename="../mainwindow.cpp" line="3215"/>
        <source>Install</source>
        <translation>መግጠሚያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1629"/>
        <source>Alt+I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1648"/>
        <source>Quit application</source>
        <translation>መተግበሪያ ማጥፊያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1651"/>
        <source>Close</source>
        <translation>መዝጊያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1657"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1689"/>
        <source>About this application</source>
        <translation>ስለዚህ መተግበሪያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1692"/>
        <source>About...</source>
        <translation>ስለ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1698"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1736"/>
        <source>Display help </source>
        <translation>እርዳታ ማሳያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1739"/>
        <source>Help</source>
        <translation>እርዳታ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1745"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1761"/>
        <source>Uninstall</source>
        <translation>ማጥፊያ </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1767"/>
        <source>Alt+U</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="179"/>
        <source>Uninstalling packages...</source>
        <translation>ጥቅል ማጥፊያ </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="184"/>
        <source>Running pre-uninstall operations...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="204"/>
        <source>Running post-uninstall operations...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="221"/>
        <source>Refreshing sources...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="235"/>
        <location filename="../mainwindow.cpp" line="1226"/>
        <location filename="../mainwindow.cpp" line="1360"/>
        <location filename="../mainwindow.cpp" line="1526"/>
        <location filename="../mainwindow.cpp" line="1583"/>
        <location filename="../mainwindow.cpp" line="1881"/>
        <location filename="../mainwindow.cpp" line="2025"/>
        <location filename="../mainwindow.cpp" line="2356"/>
        <location filename="../mainwindow.cpp" line="2375"/>
        <location filename="../mainwindow.cpp" line="2481"/>
        <location filename="../mainwindow.cpp" line="2497"/>
        <location filename="../mainwindow.cpp" line="2589"/>
        <location filename="../mainwindow.cpp" line="2622"/>
        <location filename="../mainwindow.cpp" line="3035"/>
        <location filename="../mainwindow.cpp" line="3111"/>
        <location filename="../mainwindow.cpp" line="3141"/>
        <location filename="../mainwindow.cpp" line="3232"/>
        <location filename="../mainwindow.cpp" line="3253"/>
        <source>Error</source>
        <translation>ስህተት</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="236"/>
        <source>There was a problem updating sources. Some sources may not have provided updates. For more info check: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="660"/>
        <source>Cancel</source>
        <translation>መሰረዣ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="667"/>
        <source>Please wait...</source>
        <translation>እባክዎን ይቆዩ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1046"/>
        <source>You are about to use the MX Test repository, whose packages are provided for testing purposes only. It is possible that they might break your system, so it is suggested that you back up your system and install or update only one package at a time. Please provide feedback in the Forum so the package can be evaluated before moving up to Main.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1055"/>
        <source>You are about to use Debian Backports, which contains packages taken from the next Debian release (called &apos;testing&apos;), adjusted and recompiled for usage on Debian stable. They cannot be tested as extensively as in the stable releases of Debian and MX Linux, and are provided on an as-is basis, with risk of incompatibilities with other components in Debian stable. Use with care!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1063"/>
        <source>MX Linux includes this repository of flatpaks for the users&apos; convenience only, and is not responsible for the functionality of the individual flatpaks themselves. For more, consult flatpaks in the Wiki.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1071"/>
        <location filename="../mainwindow.cpp" line="3241"/>
        <source>Warning</source>
        <translation>ማስጠንቀቂያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1075"/>
        <source>Do not show this message again</source>
        <translation>ይህን መልእክት በድጋሚ አታሳየኝ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1175"/>
        <source>Remove</source>
        <translation>ማስወገጃ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1191"/>
        <source>The following packages were selected. Click Show Details for list of changes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1227"/>
        <location filename="../mainwindow.cpp" line="1361"/>
        <location filename="../mainwindow.cpp" line="1584"/>
        <source>Internet is not available, won&apos;t be able to download the list of packages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1230"/>
        <source>Installing packages...</source>
        <translation>ጥቅሎች በ መግጠም ላይ ላይ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1285"/>
        <source>Post-processing...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1317"/>
        <source>Pre-processing for </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1332"/>
        <source>Installing </source>
        <translation>በ መግጠም ላይ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1339"/>
        <source>Post-processing for </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1527"/>
        <source>There was an error downloading or writing the file: %1. Please check your internet connection and free space on your drive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1592"/>
        <source>Downloading package info...</source>
        <translation>የ ጥቅል መረጃ በ ማውረድ ላይ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1882"/>
        <source>dpkg-query command returned an error. Please run &apos;dpkg-query -W&apos; in terminal and check the output.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2026"/>
        <source>dpkg command returned an error, please run &apos;dpkg --list&apos; in terminal and check the output.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2104"/>
        <location filename="../mainwindow.cpp" line="2191"/>
        <location filename="../mainwindow.cpp" line="2214"/>
        <source>Package info</source>
        <translation>ጥቅል መረጃ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2121"/>
        <location filename="../mainwindow.cpp" line="3179"/>
        <source>More &amp;info...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2152"/>
        <source>Packages to be installed: </source>
        <translation>የሚገጠመው ጥቅል:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2340"/>
        <location filename="../mainwindow.cpp" line="2352"/>
        <location filename="../mainwindow.cpp" line="2372"/>
        <location filename="../mainwindow.cpp" line="2456"/>
        <location filename="../mainwindow.cpp" line="2478"/>
        <location filename="../mainwindow.cpp" line="3032"/>
        <location filename="../mainwindow.cpp" line="3107"/>
        <location filename="../mainwindow.cpp" line="3135"/>
        <location filename="../mainwindow.cpp" line="3228"/>
        <source>Done</source>
        <translation>ጨርሷል</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2340"/>
        <location filename="../mainwindow.cpp" line="2352"/>
        <location filename="../mainwindow.cpp" line="2372"/>
        <location filename="../mainwindow.cpp" line="2456"/>
        <location filename="../mainwindow.cpp" line="2478"/>
        <location filename="../mainwindow.cpp" line="2494"/>
        <location filename="../mainwindow.cpp" line="3032"/>
        <location filename="../mainwindow.cpp" line="3107"/>
        <location filename="../mainwindow.cpp" line="3135"/>
        <location filename="../mainwindow.cpp" line="3228"/>
        <location filename="../mainwindow.cpp" line="3250"/>
        <source>Processing finished successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2357"/>
        <location filename="../mainwindow.cpp" line="2376"/>
        <location filename="../mainwindow.cpp" line="3036"/>
        <location filename="../mainwindow.cpp" line="3112"/>
        <location filename="../mainwindow.cpp" line="3142"/>
        <source>Problem detected while installing, please inspect the console output.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2386"/>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2387"/>
        <source>Version: </source>
        <translation>እትም</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2389"/>
        <source>Package Installer for MX Linux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2391"/>
        <source>Copyright (c) MX Linux</source>
        <translation>የ ቅጂ መብት (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2392"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2404"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2481"/>
        <source>We encountered a problem uninstalling, please check output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2494"/>
        <location filename="../mainwindow.cpp" line="3250"/>
        <source>Success</source>
        <translation>ተሳክቷል</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2497"/>
        <location filename="../mainwindow.cpp" line="3253"/>
        <source>We encountered a problem uninstalling the program</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2590"/>
        <location filename="../mainwindow.cpp" line="2623"/>
        <source>Could not download the list of packages. Please check your APT sources.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2662"/>
        <location filename="../mainwindow.cpp" line="2702"/>
        <source>Flatpak not installed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2663"/>
        <source>Flatpak is not currently installed.
OK to go ahead and install it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2702"/>
        <source>Flatpak was not installed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2725"/>
        <source>Needs re-login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2726"/>
        <source>You might need to logout/login to see installed items in the menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2837"/>
        <location filename="../mainwindow.cpp" line="2845"/>
        <location filename="../mainwindow.cpp" line="2937"/>
        <source>Mark keep</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2935"/>
        <source>Upgrade</source>
        <translation>ማሻሻያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3064"/>
        <source>Quit?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3065"/>
        <source>Process still running, quitting might leave the system in an unstable state.&lt;p&gt;&lt;b&gt;Are you sure you want to exit MX Package Installer?&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3213"/>
        <source>Reinstall</source>
        <translation>እንደገና መግጠሚያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3233"/>
        <source>Problem detected during last operation, please inspect the console output.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3242"/>
        <source>Potentially dangerous operation.
Please make sure you check carefully the list of packages to be removed.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ManageRemotes</name>
    <message>
        <location filename="../remotes.cpp" line="16"/>
        <source>Manage Flatpak Remotes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="23"/>
        <source>For all users</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="24"/>
        <source>For current user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="35"/>
        <source>enter Flatpak remote URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="38"/>
        <source>enter Flatpakref location to install app</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="40"/>
        <source>Add or remove flatpak remotes (repos), or install apps using flatpakref URL or path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="49"/>
        <source>Remove remote</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="54"/>
        <source>Add remote</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="59"/>
        <source>Install app</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="64"/>
        <source>Close</source>
        <translation>መዝጊያ</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="81"/>
        <source>Not removable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="82"/>
        <source>Flathub is the main Flatpak remote and won&apos;t be removed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="101"/>
        <source>Error adding remote</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="102"/>
        <source>Could not add remote - command returned an error. Please double-check the remote address and try again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="107"/>
        <source>Success</source>
        <translation>ተሳክቷል</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="107"/>
        <source>Remote added successfully</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="71"/>
        <source>License</source>
        <translation>ፍቃድ</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <location filename="../about.cpp" line="82"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="73"/>
        <source>Cancel</source>
        <translation>መሰረዣ</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="95"/>
        <source>&amp;Close</source>
        <translation>&amp;መዝጊያ</translation>
    </message>
    <message>
        <location filename="../lockfile.cpp" line="50"/>
        <source>Warning</source>
        <translation>ማስጠንቀቂያ</translation>
    </message>
    <message>
        <location filename="../lockfile.cpp" line="51"/>
        <source>Dpkg/apt database is locked by another program: %1
Close the program, or wait until it is done processing and try again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="78"/>
        <source>MX Package Installer is a tool used for managing packages on MX Linux
    - installs popular programs from different sources
    - installs programs from the MX Test repo
    - installs programs from Debian Backports repo
    - installs flatpaks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="86"/>
        <source>Skip online check if it falsely reports lack of internet access.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="96"/>
        <location filename="../main.cpp" line="104"/>
        <source>Error</source>
        <translation>ስህተት</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="97"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="105"/>
        <source>You must run this program with admin access.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
